@@ -77,7 +77,7 @@ def G(c_componente):#Guardar
     DatosList.append(c_componente)#Si el emento no estaba adentro, simplemente lo agregamos.
   
   #Renderizado Gris
-  if c_componente[1] == None:
+  if c_componente[1] == None or dentro == False:
     D(c_componente,"gray")#Hacemos un print renderizado en color gris para indicar que el elemento ha sido definido/guardado
   else:
     D(c_componente,"red")#Hacemos un print renderizado en color gris para indicar que el elemento ha sido definido/guardado
